#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IWidgetForm, IFormHelp, IFormContextPermissionChecker
from pyams_i18n.interfaces import II18nManager
from pyams_skin.interfaces import IInnerPage
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION, MANAGE_PERMISSION
from pyams_zmi.interfaces.menu import ISiteManagementMenu
from pyams_zmi.layer import IAdminLayer

# import packages
from pyams_form.form import AJAXEditForm
from pyams_form.help import FormHelp
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.adapter import adapter_config, ContextRequestViewAdapter
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminEditForm
from pyramid.view import view_config
from z3c.form import field
from zope.interface import implementer

from pyams_i18n import _


#
# Content languages
#

@viewlet_config(name='languages.menu', context=II18nManager, layer=IAdminLayer,
                manager=ISiteManagementMenu, permission=VIEW_SYSTEM_PERMISSION, weight=100)
class I18nManagerLanguagesMenu(MenuItem):
    """I18n manager languages menu"""

    label = _("Languages")
    icon_class = 'fa-flag'

    url = '#languages.html'


@pagelet_config(name='languages.html', context=II18nManager, layer=IPyAMSLayer, permission=VIEW_SYSTEM_PERMISSION)
@implementer(IInnerPage, IWidgetForm)
class I18nManagerLanguagesEditForm(AdminEditForm):
    """I18n manager languages edit form"""

    legend = _("Content languages")

    fields = field.Fields(II18nManager)
    ajax_handler = 'languages.json'
    edit_permission = None


@view_config(name='languages.json', context=II18nManager, request_type=IPyAMSLayer,
             permission=VIEW_SYSTEM_PERMISSION, renderer='json', xhr=True)
class I18nManagerLanguagesAJAXEditForm(AJAXEditForm, I18nManagerLanguagesEditForm):
    """I18n manager languages edit form, JSON renderer"""


@adapter_config(context=(II18nManager, IPyAMSLayer, I18nManagerLanguagesEditForm), provides=IFormHelp)
class I18nManagerLanguageEditFormHelp(FormHelp):
    """I18n manager language edit form help adapter"""

    outer_margin = 10
    message = _("For each selected language, a tab will be associated to each form input to enter matching "
                "translation.")
    message_format = 'rest'


@adapter_config(context=(II18nManager, IPyAMSLayer, I18nManagerLanguagesEditForm),
                provides=IFormContextPermissionChecker)
class I18nManagerLanguageEditFormPermissionChecker(ContextRequestViewAdapter):
    """I18n manager language edit form permission checker"""

    edit_permission = MANAGE_PERMISSION
